/* Copyright (C) 2017 by Bundesanstalt für Gewässerkunde
 * Software engineering by
 *  Björnsen Beratende Ingenieure GmbH
 *  Dr. Schumacher Ingenieurbüro für Wasser und Umwelt
 *
 * This file is Free Software under the GNU AGPL (>=v3)
 * and comes with ABSOLUTELY NO WARRANTY! Check out the
 * documentation coming with Dive4Elements River for details.
 */
package org.dive4elements.river.artifacts.sinfo.flowdepth;

import java.io.Serializable;

/**
 * Part of {@link FlowDepthCalculationResult} which represents one calculated row of flow depth data.
 *
 * @author Gernot Belger
 */
final class FlowDepthRow implements Serializable {
    private static final long serialVersionUID = 1L;

    private final double station;

    private final double flowDepth;

    private final double flowDepthWithTkh;

    private final SoilKind tkhKind;

    private final double tkh;

    private final double tkhUp;

    private final double tkhDown;

    private final double waterlevel;

    private final double discharge;

    private final String waterlevelLabel;

    private final String gauge;

    private final double meanBedHeight;

    private final String soundageLabel;

    private final String location;

    public FlowDepthRow(final double station, final double flowDepth, final double flowDepthWithTkh, final SoilKind tkhKind, final double tkh,
            final double tkhUp, final double tkhDown,
            final double waterlevel, final double discharge, final String waterlevelLabel, final String gauge, final double meanBedHeight,
            final String soundageLabel, final String location) {
        this.station = station;
        this.flowDepth = flowDepth;
        this.flowDepthWithTkh = flowDepthWithTkh;
        this.tkhKind = tkhKind;
        this.tkh = tkh;
        this.tkhUp = tkhUp;
        this.tkhDown = tkhDown;
        this.waterlevel = waterlevel;
        this.discharge = discharge;
        this.waterlevelLabel = waterlevelLabel;
        this.gauge = gauge;
        this.meanBedHeight = meanBedHeight;
        this.soundageLabel = soundageLabel;
        this.location = location;
    }

    public double getStation() {
        return this.station;
    }

    public double getFlowDepth() {
        return this.flowDepth;
    }

    public double getFlowDepthWithTkh() {
        return this.flowDepthWithTkh;
    }

    public SoilKind getTkhKind() {
        return this.tkhKind;
    }

    public double getTkh() {
        return this.tkh;
    }

    public double getTkhUp() {
        return this.tkhUp;
    }

    public double getTkhDown() {
        return this.tkhDown;
    }

    public double getWaterlevel() {
        return this.waterlevel;
    }

    public double getDischarge() {
        return this.discharge;
    }

    public String getWaterlevelLabel() {
        return this.waterlevelLabel;
    }

    public String getGauge() {
        return this.gauge;
    }

    public double getMeanBedHeight() {
        return this.meanBedHeight;
    }

    public String getSoundageLabel() {
        return this.soundageLabel;
    }

    public String getLocation() {
        return this.location;
    }
}